( cd opt/kde/share/doc/HTML/ca/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdm ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/amor ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kate ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdat ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kgpg ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmag ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kodo ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/krdc ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/krdc ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/krfb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ksim ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kxkb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/katomic ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ksysguard ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khangman ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpercentage ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdcop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdcop ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdesu ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcron ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kfind ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmail ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmoon ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ktnef ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ktnef ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ksysv ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kttsd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kttsd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kuser ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/klipper ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmousetool ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kompare ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kompmgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kompmgr ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kontact ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konsole ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpackage ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/lilo-config ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/lilo-config ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kwallet ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kweather ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kioslave ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/knetattach ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/knetattach ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/performance ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/crashes ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/babel ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/kuick ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/webarchiver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/domtreeviewer ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/smbmounter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/imgallery ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/khtmlsettings ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/validators ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/fsview ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/uachanger ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/mediaplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/dirfilter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdeprint ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kbruch ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/keduca ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kicker ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmouth ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kspell ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kstars ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ktimer ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ktouch ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kwrite ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/ksplashml ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcharselect ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/quanta ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/klettres ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/klickety ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kgeography ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kgeography ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kleopatra ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kteatime ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/knetworkconf ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/cdinfo ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/opengl ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/konqueror ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kwordquiz ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
